QuicBuffer class

A simple buffer to read data sequentially from a Uint8List.

Constructors

QuicBuffer({Uint8List? data})

Properties

byteData → ByteData
no setter
capacity → int
The total capacity of the buffer.
no setter
data → Uint8List
no setter
eof → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
readOffset → int
no setter
remaining → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeIndex → int
no setter

Methods

getUint32() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
position({int? offset}) → int
pullBytes(int len) → Uint8List
pullUint16() → int
pullUint24() → int
pullUint32() → int
pullUint8() → int
pullVarInt() → int
pullVector(int lenBytes) → Uint8List
pushBytes(Uint8List bytes) → void
pushUint16(int value) → void
pushUint24(int value) → void
pushUint32(int value) → void
pushUint8(int value) → void
pushVarint(int value) → void
pushVector(Uint8List bytes, int lenBytes) → void
tell() → int
The current read position.
toBytes() → Uint8List
toString() → String
A string representation of this object.
inherited
viewBytes(int length, {int offset = 0}) → Uint8List

Operators

operator ==(Object other) → bool
The equality operator.
inherited