EcdsaCert class


Local certificate model used by the QUIC server

Constructors

EcdsaCert({required Uint8List privateKey, required Uint8List publickKey, required Uint8List cert, required Uint8List fingerPrint})

Properties

cert Uint8List
getter/setter pair
fingerPrint Uint8List
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
privateKey Uint8List
getter/setter pair
publickKey Uint8List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited