KeyPair class

Properties

hashCode int
The hash code for this object.
no setterinherited
privateKeyBytes Uint8List
Raw 32-byte X25519 private key.
no setter
publicKeyBytes Uint8List
Raw 32-byte X25519 public key. Raw 32-byte X25519 public key.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate() KeyPair