ClientHello class

Inheritance

Constructors

ClientHello({required int legacyVersion, required Uint8List sessionId, required Uint8List random, required List<int> cipherSuites, required Uint8List compressionMethods, required List<TlsExtension> extensions, required String type, String? sni, List<ParsedKeyShare>? keyShares, List<int>? supportedVersions, List<int>? supportedGroups, List<int>? signatureAlgorithms, List<String>? alpn, int? maxFragmentLength, Uint8List? padding, Uint8List? cookie, List<int>? pskKeyExchangeModes, Uint8List? preSharedKey, Uint8List? renegotiationInfo, Uint8List? quicTransportParametersRaw, required Uint8List rawData})

Properties

alpn List<String>?
getter/setter pair
alpnProtocols List<String>
getter/setter pair
cipherSuites List<int>
final
compressionMethods Uint8List
getter/setter pair
getter/setter pair
extensions List<TlsExtension>
final
hashCode int
The hash code for this object.
no setterinherited
keyShares List<ParsedKeyShare>?
getter/setter pair
legacyVersion int
getter/setter pair
maxFragmentLength int?
getter/setter pair
msgType int
finalinherited
padding Uint8List?
getter/setter pair
preSharedKey Uint8List?
getter/setter pair
pskKeyExchangeModes List<int>?
getter/setter pair
quicTransportParametersRaw Uint8List?
getter/setter pair
random Uint8List
final
rawData Uint8List
final
renegotiationInfo Uint8List?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId Uint8List
getter/setter pair
signatureAlgorithms List<int>?
getter/setter pair
sni String?
getter/setter pair
supportedGroups List<int>?
getter/setter pair
supportedVersions List<int>?
getter/setter pair
typeName String
no setterinherited

Methods

build_tls_client_hello() Uint8List
build_tls_client_hello2() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseExtensions(QuicBuffer buffer) List<TlsExtension>
serialize() Uint8List
toString() String
A string representation of this object.
override
upsertAlpnExtension() → void
Replace or insert the ALPN extension (0x0010) based on alpn.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse_tls_client_hello(Uint8List body) ClientHello