EncryptedExtensions class

Inheritance

Constructors

EncryptedExtensions({required List<TlsExtension> extensions})

Properties

extensions List<TlsExtension>
final
hashCode int
The hash code for this object.
no setterinherited
msgType int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeName String
no setterinherited

Methods

build() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(QuicBuffer buf) EncryptedExtensions