ServerHello class

Inheritance

Constructors

ServerHello({required int legacyVersion, required Uint8List random, required Uint8List sessionId, required int cipherSuite, required int compressionMethod, required Map<int, Uint8List> extensionsRaw, required int msgType, ParsedKeyShare? keyShareEntry, int? selectedVersion, Uint8List? rawBytes})

Properties

cipherSuite int
final
compressionMethod int
final
extensionsRaw Map<int, Uint8List>
final
hashCode int
The hash code for this object.
no setterinherited
keyShareEntry ParsedKeyShare?
final
legacyVersion int
final
msgType int
finalinherited
random Uint8List
final
rawBytes Uint8List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedVersion int?
final
sessionId Uint8List
final
typeName String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(QuicBuffer buf) ServerHello