VarIntReadResult class

Represents the result of reading a Variable-Length Integer (VarInt).

Constructors

VarIntReadResult({required int value, required int byteLength})
const

Properties

byteLength → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited