ByteReader class

Constructors

ByteReader(Uint8List _data)

Properties

hashCode int
The hash code for this object.
no setterinherited
remaining int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(int i) → void
peek(int n) Uint8List
peekUint8() int
readBytes(int n) Uint8List
readInt16be() int
readInt8() int
readUint16be() int
readUint8() int
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited