AckFrame class

Inheritance

Constructors

AckFrame({required int largest, required int delay, required int firstRange, required List ranges, dynamic ecn})

Properties

delay int
final
ecn → dynamic
final
firstRange int
final
hashCode int
The hash code for this object.
no setterinherited
largest int
final
ranges List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited