QuicStreamReassembler class

Constructors

QuicStreamReassembler()

Properties

hashCode int
The hash code for this object.
no setterinherited
readOffset int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Hard reset (rarely needed, but useful on stream close)
drain() Uint8List
Drain all contiguous bytes starting at readOffset. Returns empty Uint8List if nothing is ready.
insert(int offset, Uint8List data) → void
Insert a received stream chunk. Safe to call multiple times with retransmissions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited